# BillingSummary


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**subscription** | [**StripeSubscription**](StripeSubscription.md) |  | [optional] 
**customer** | [**StripeCustomer**](StripeCustomer.md) |  | 
**user** | [**User**](User.md) |  | [optional] 
**billing_portal_url** | **str** |  | [readonly] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


